[jboss-cvs] JBossAS SVN: r84194 - branches/Branch_5_0/server/src/main/org/jboss/web/deployers.

jboss-cvs-commits at lists.jboss.org jboss-cvs-commits at lists.jboss.org
Fri Feb 13 17:05:07 EST 2009


Author: alesj
Date: 2009-02-13 17:05:06 -0500 (Fri, 13 Feb 2009)
New Revision: 84194

Modified:
   branches/Branch_5_0/server/src/main/org/jboss/web/deployers/AbstractWarDeployer.java
Log:
Use vfs to delete the temp war file, cleanup usage.

Modified: branches/Branch_5_0/server/src/main/org/jboss/web/deployers/AbstractWarDeployer.java
===================================================================
--- branches/Branch_5_0/server/src/main/org/jboss/web/deployers/AbstractWarDeployer.java	2009-02-13 21:50:35 UTC (rev 84193)
+++ branches/Branch_5_0/server/src/main/org/jboss/web/deployers/AbstractWarDeployer.java	2009-02-13 22:05:06 UTC (rev 84194)
@@ -463,9 +463,9 @@
          URL warURL = unit.getAttachment("org.jboss.web.expandedWarURL", URL.class);
          if (warURL != null)
          {
             // use vfs to delete - since we created it with vfs
             VirtualFile file = VFS.getRoot(warURL);
-            file.delete();
+            file.cleanup(); // it's temp, it will be deleted as well
          }
       }
       catch (Exception e)
@@ -463,9 +463,9 @@
          if (warURL != null)
          {
-            // use vfs to delete - since we created it with vfs
+            // use vfs to cleanup/delete - since we created it with vfs
             VirtualFile file = VFS.getRoot(warURL);




More information about the jboss-cvs-commits mailing list